#include <stdarg.h>
#include "app_uart.h"
#include "nordic_common.h"
#include "nrf51.h"
#include "nrf51_bitfields.h"
#include "board.h"

void uart_event_handler(app_uart_evt_t* p_event);

void console_init(void)
{

	app_uart_comm_params_t uart_comm_params;

	uart_comm_params.baud_rate = UART_BAUDRATE_BAUDRATE_Baud38400;
	uart_comm_params.cts_pin_no = CTS_PIN_NUMBER;
	uart_comm_params.rts_pin_no = RTS_PIN_NUMBER;
	uart_comm_params.tx_pin_no = TX_PIN_NUMBER;
	uart_comm_params.rx_pin_no = RX_PIN_NUMBER;
	uart_comm_params.flow_control = APP_UART_FLOW_CONTROL_DISABLED;
	uart_comm_params.use_parity = false;


	__attribute__((unused)) uint32_t error = 0;

	APP_UART_FIFO_INIT(
		&uart_comm_params,
		32, 					// RX_BUF_SIZE,
		32,						// TX_BUF_SIZE,
		uart_event_handler,		// EVT_HANDLER,
		APP_IRQ_PRIORITY_LOW, 	// IRQ_PRIO,
		error
		);


//    simple_uart_config(RTS_PIN_NUMBER, TX_PIN_NUMBER, CTS_PIN_NUMBER, RX_PIN_NUMBER, false);//HWFC);
}

void myputc(int ch)
{
    app_uart_put((uint8_t)ch);
}
#include <stdarg.h>

char *digits="0123456789abcdef";

void _printNumber(int base, unsigned int x)
{
	if (x > 0) {
		int digit = x % base;
		_printNumber(base, x / base);
		myputc(digits[digit]);
	}
}

void printNumber(int base, int x)
{
	if (x == 0)
	{
		myputc('0');
	}
	else if (base == 16)
	{
		myputc('0');
		myputc('x');
		_printNumber(base, (unsigned int)x);
	}
	else if (x < 0)
	{
		myputc('-');
		_printNumber(base, (unsigned int)-x);
	}
	else
	{
		_printNumber(base, (unsigned int)x);
	}
}

int printf(const char * restrict format, ...)
{
    va_list ap;
    va_start(ap, format); //Requires the last fixed parameter (to get the address)
	for (; *format != 0; format++)
	{
		switch(*format) {
		case '%':
			switch(*++format) {
			case 'l':
				break;
			case 'd':
				printNumber(10, va_arg(ap, int));
				break;
			case 'x':
				printNumber(16, va_arg(ap, int));
				break;
			case 'c':
				myputc(va_arg(ap, int));
				break;
			case '%':
				myputc('%');
				break;
			}
			break;
		default:
			myputc(*format);
			break;
		}
	}
	va_end(ap);
	return 0;
}

void uart_event_handler(app_uart_evt_t* p_event)
{
	uint8_t c;
	switch(p_event->evt_type)
	{
	case APP_UART_DATA_READY:
		if (app_uart_get(&c) == NRF_SUCCESS) {
			printf("%c what?\r\n", c);
		}
		break;
	default:
		break;
	}
}


